Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultAPIResourceConfigSource ¶
func DefaultAPIResourceConfigSource() *serverstorage.ResourceConfig
DefaultAPIResourceConfigSource returns which groupVersion enabled and its resources enabled/disabled.
Types ¶
type APIServer ¶
type APIServer struct {
GenericAPIServer *genericapiserver.GenericAPIServer
}
APIServer contains state for a tke api server.
func (*APIServer) InstallAPIs ¶
func (m *APIServer) InstallAPIs(apiResourceConfigSource serverstorage.APIResourceConfigSource, restOptionsGetter generic.RESTOptionsGetter, restStorageProviders ...storage.RESTStorageProvider)
InstallAPIs will install the APIs for the restStorageProviders if they are enabled.
type CompletedConfig ¶
type CompletedConfig struct {
// contains filtered or unexported fields
}
CompletedConfig embed a private pointer of Config.
func (CompletedConfig) New ¶
func (c CompletedConfig) New(delegationTarget genericapiserver.DelegationTarget) (*APIServer, error)
New returns a new instance of APIServer from the given config.
type Config ¶
type Config struct {
GenericConfig *genericapiserver.RecommendedConfig
ExtraConfig ExtraConfig
}
Config contains the core configuration instance of apiserver and additional configuration.
func (*Config) Complete ¶
func (cfg *Config) Complete() CompletedConfig
Complete fills in any fields not set that are required to have valid data. It's mutating the receiver.
type ExtraConfig ¶
type ExtraConfig struct {
ServerName string
APIResourceConfigSource serverstorage.APIResourceConfigSource
StorageFactory serverstorage.StorageFactory
VersionedInformers versionedinformers.SharedInformerFactory
PlatformClient platformversionedclient.PlatformV1Interface
BusinessClient businessversionedclient.BusinessV1Interface
PrivilegedUsername string
MonitorConfig *monitorconfig.MonitorConfiguration
}
ExtraConfig contains the additional configuration of apiserver.
Click to show internal directories.
Click to hide internal directories.